//
// Copyright Amazon.com Inc. or its affiliates.
// All Rights Reserved.
//
// SPDX-License-Identifier: Apache-2.0
//

import Foundation

extension DeviceSRPState: CustomDebugDictionaryConvertible {

    var debugDictionary: [String: Any] {

        let additionalMetadataDictionary: [String: Any]
        switch self {
        case .notStarted:
            additionalMetadataDictionary = [:]
        case .initiatingDeviceSRP:
            additionalMetadataDictionary = [:]
        case .cancelling:
            additionalMetadataDictionary = [:]
        case .respondingDevicePasswordVerifier(let srpStateData):
            additionalMetadataDictionary = srpStateData.debugDictionary
        case .signedIn(let signedInData):
            additionalMetadataDictionary = signedInData.debugDictionary
        case .error(let error):
            additionalMetadataDictionary = [
                "Error": error
            ]
        }
        return [type: additionalMetadataDictionary]
    }
}
